!Copyright 2016 J.-M. CHESNEAUX, F. JEZEQUEL, J.-L. LAMOTTE
!
!This file is part of CADNA.
!
!    CADNA is free software: you can redistribute it and/or modify it
!    under the terms of the GNU Lesser General Public License as
!    published by the Free Software Foundation, either version 3 of the
!    License, or (at your option) any later version.
!
!    CADNA is distributed in the hope that it will be useful, but WITHOUT
!    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
!    or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General
!    Public License for more details.
!
!    You should have received a copy of the GNU Lesser General Public
!    License along with CADNA. If not, see
!    <http://www.gnu.org/licenses/>.
!
!****if instability
!  NAME
!    instability
!
!  FUNCTION
!    It is an internal subroutine of the CADNA library. It manages 
!    the different kinds of instabilities detected CADNA.
!
!  INPUTS
!    An integer which indicates the kind of instability that has been 
!    detected.
!  
!  NOTES
!    This function is called exclusively when an instability has been 
!    detected. Therefore, under a symbolic debugger like gdb, one has
!    only to put a breakoint at this function to stop the run each
!    time an instability occurs. 
!
!******
subroutine instability(cadna_inst)
  use cadna_type
  implicit none
  integer :: cadna_inst
  cadna_numb_error = cadna_numb_error + 1
  if (cadna_numb_error_max.lt.0.or.cadna_numb_error.le.cadna_numb_error_max) then
     SELECT CASE (cadna_inst)
     CASE (cadna_branching)
        cadna_branching_count = cadna_branching_count + 1
     CASE (cadna_mathematic)
        cadna_mathematic_count = cadna_mathematic_count + 1
     CASE (cadna_intrinsic)
        cadna_intrinsic_count = cadna_intrinsic_count + 1
     CASE (cadna_cancellation)
        cadna_cancellation_count = cadna_cancellation_count + 1
     CASE (cadna_division)
        cadna_division_count = cadna_division_count + 1
     CASE (cadna_power)
        cadna_power_count = cadna_power_count + 1
     CASE (cadna_multiplication)
        cadna_multiplication_count = cadna_multiplication_count + 1
     END SELECT
  else
     cadna_numb_error_max = 0
     cadna_division_tag = .false.
     cadna_power_tag = .false.
     cadna_multiplication_tag = .false.
     deactivate = .true.
     cadna_branching_tag = .false.
     cadna_mathematic_tag = .false.
     cadna_intrinsic_tag = .false.
     cadna_cancellation_tag = .false.
  end if
end subroutine instability
